@@ -36,7 +36,7 @@ def pythagorean(a, b):
 	c=sqrtofn(c2)
 	return c
 
-
+ 
 def Fibonacci(n):
     if n<=0:
         print("Incorrect input")
@@ -49,9 +49,31 @@ def Fibonacci(n):
     else:
         return Fibonacci(n-1)+Fibonacci(n-2)
 
-def sin(angle):
-	return math.sin(angle)
-def cosine(angle):
-	return math.cos(angle)
-def tan(angle):
-	return math.tan(angle)
+class RightTriangle:
+    def __init__(self, angleone, hypotenuse, leg1, leg2):
+        self.1stangle=angleone
+        self.s1=hypotenuse
+        self.s2=leg1
+        self.s3=leg2
+    def draw(self):
+        import turtle
+        turtle.rt(90)
+        turtle.fd(self.s2)
+        turtle.lt(90)
+        turtle.fd(self.s3)
+        turtle.lt(self.1stangle)
+        turtle.fd(self.s1)
+
+def absval(x):
+    if x<0:
+        return -x
+    elif x>=0:
+        return x
+    else:
+        return "enter a valid number"
+
+def graph_equation(formula, x_range):
+    x = numpy.array(x_range)
+    y = eval(formula)
+    plt.plot(x, y)
+    plt.show()
